@@ -1,5 +1,3 @@
-/* $Id: proctime.c 2492 2006-06-24 17:47:34Z bdejean $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -34,7 +32,7 @@ static const unsigned long _glibtop_sysdeps_proc_time =
 /* Init function. */
 
 void
-glibtop_init_proc_time_s (glibtop *server)
+_glibtop_init_proc_time_s (glibtop *server)
 {
 	server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
 }
